@@ -2,10 +2,30 @@
 #
 # mercurial_keyring: save passwords in password database
 #
-# Copyright 2009 Marcin Kasperski <Marcin.Kasperski@mekk.waw.pl>
+# Copyright (c) 2009 Marcin Kasperski <Marcin.Kasperski@mekk.waw.pl>
+# All rights reserved.
 #
-# This software may be used and distributed according to the terms
-# of the GNU General Public License, incorporated herein by reference.
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted provided that the following conditions
+# are met:
+# 1. Redistributions of source code must retain the above copyright
+#    notice, this list of conditions and the following disclaimer.
+# 2. Redistributions in binary form must reproduce the above copyright
+#    notice, this list of conditions and the following disclaimer in the
+#    documentation and/or other materials provided with the distribution.
+# 3. The name of the author may not be used to endorse or promote products
+#    derived from this software without specific prior written permission.
+#
+# THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
+# IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
+# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
+# IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
+# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
+# NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
+# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #
 # See README.txt for more details.
 
@@ -17,7 +37,7 @@ command line). This extension uses and wraps services of the keyring
 library.
 '''
 
-from mercurial import hg, util
+from mercurial import util
 from mercurial.i18n import _
 try:
     from mercurial.url import passwordmgr
@@ -32,6 +52,10 @@ from urllib2 import AbstractBasicAuthHandler, AbstractDigestAuthHandler
 from mercurial.demandimport import ignore
 if "gobject._gobject" not in ignore:
     ignore.append("gobject._gobject")
+    ignore.append("configparser")
+    ignore.append("json")
+    ignore.append("abc")
+    ignore.append("io")
 
 import keyring
 from urlparse import urlparse
@@ -83,7 +107,7 @@ class PasswordStore(object):
             self._format_smtp_key(machine, port, username),
             password)
     def clear_smtp_password(self, machine, port, username):
-        self.set_smtp_password(url, username, "")
+        self.set_smtp_password(machine, port, username, "")
     def _format_smtp_key(self, machine, port, username):
         return "%s@@%s:%s" % (username, machine, str(port))
 
